==> rheolef_5.93.orig.tar.gz: rheolef-5.93/nfem/pform_element/grad_grad.h <==
#ifndef _RHEOLEF_GRAD_GRAD_H
#define _RHEOLEF_GRAD_GRAD_H
///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
/// 
/// =========================================================================

#include "rheolef/form_element.h"

namespace rheolef { 

/*Class:grad_grad
NAME: @code{grad_grad} -- -Laplacian operator
@bfindex grad_grad
@cindex Laplacian
@apindex P1
@apindex P2
@apindex P1d
SYNOPSIS:
    @example
      form(const space V, const space& V, "grad_grad");
    @end example
DESCRIPTION:       
    @noindent
    Assembly the form associated to the
    Laplacian operator on a finite element space @code{V}:
@iftex  
    $$ 
      a(u,v) = \int_\Omega \nabla u . \nabla v \, dx
    $$ 
@end iftex  
@ifnottex  
    @example
               /
               |
      a(u,v) = |  grad(u).grad(v) dx
               |
               / Omega
    @end example
@end ifnottex  
    @noindent
    The V space may be a either
    @code{P1} , @code{P2}  or @code{P1d}  finite element space.
    See also @ref{form class} and @ref{space class}.

EXAMPLE:
    @noindent
    The following piece of code build the Laplacian form
    associated to the @code{P1} approximation:
    @example
   	geo g("square");
   	space V(g, "P1");
   	form a(V, V, "grad_grad");
    @end example
AUTHOR: 
    LMC-IMAG, 38041 Grenoble cedex 9, France
    | Pierre.Saramito@imag.fr
DATE:
    28 november 1997
End:
*/
template<class T, class M>
class grad_grad: public form_element_rep<T,M> {
public:
    typedef form_element_rep<T,M>       base;
    typedef typename base::size_type    size_type;
    typedef typename base::geo_type     geo_type;
    typedef typename base::element_type element_type;

    grad_grad (const element_type& X, const element_type& Y, const geo_type& omega)
	: form_element_rep<T,M> (X,Y,omega) { this->initialize_all(); }

    void operator() (const geo_element& K, ublas::matrix<T>& m) const;
    void initialize ();
    bool is_symmetric () const { return true; }
};

}// namespace rheolef
#endif // _RHEOLEF_GRAD_GRAD_H

==> rheolef_6.1.orig.tar.gz: rheolef-6.1/nfem/pform_element/grad_grad.h <==
#ifndef _RHEOLEF_GRAD_GRAD_H
#define _RHEOLEF_GRAD_GRAD_H
///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
/// 
/// =========================================================================

#include "rheolef/form_element.h"

namespace rheolef { 

/*Class:grad_grad
NAME: @code{grad_grad} -- -Laplacian operator
@bfindex grad_grad
@cindex Laplacian
@apindex P1
@apindex P2
@apindex P1d
SYNOPSIS:
    @example
      form(const space V, const space& V, "grad_grad");
    @end example
DESCRIPTION:       
    @noindent
    Assembly the form associated to the
    Laplacian operator on a finite element space @code{V}:
@iftex  
    $$ 
      a(u,v) = \int_\Omega \nabla u . \nabla v \, dx
    $$ 
@end iftex  
@ifnottex  
    @example
               /
               |
      a(u,v) = |  grad(u).grad(v) dx
               |
               / Omega
    @end example
@end ifnottex  
    @noindent
    The V space may be a either
    @code{P1} , @code{P2}  or @code{P1d}  finite element space.
    See also @ref{form class} and @ref{space class}.

EXAMPLE:
    @noindent
    The following piece of code build the Laplacian form
    associated to the @code{P1} approximation:
    @example
   	geo g("square");
   	space V(g, "P1");
   	form a(V, V, "grad_grad");
    @end example
AUTHOR: 
    LMC-IMAG, 38041 Grenoble cedex 9, France
    | Pierre.Saramito@imag.fr
DATE:
    28 november 1997
End:
*/
template<class T, class M>
class grad_grad: public form_element_rep<T,M> {
public:
    typedef form_element_rep<T,M>       base;
    typedef typename base::size_type    size_type;
    typedef typename base::geo_type     geo_type;
    typedef typename base::space_type   space_type;

    grad_grad (const space_type& X, const space_type& Y, const geo_type& omega, 
        const quadrature_option_type& qopt)
	: form_element_rep<T,M> (X,Y,omega,qopt) { base::initialize_all(); }

    void operator() (const geo_element& K, ublas::matrix<T>& m) const;
    void initialize () const;
    bool is_symmetric () const { return true; }
};

}// namespace rheolef
#endif // _RHEOLEF_GRAD_GRAD_H
